@@ -40,7 +40,7 @@ MINIO_STORAGE_MEDIA_BUCKET_NAME = env.str(
 MINIO_STORAGE_AUTO_CREATE_MEDIA_BUCKET = env.str(
     "MINIO_STORAGE_AUTO_CREATE_MEDIA_BUCKET", default=True
 )
-MINIO_PRESIGNED_TTL_MINUTES = env.str("MINIO_PRESIGNED_TTL_MINUTES", default=15)
+MINIO_PRESIGNED_TTL_MINUTES = env.int("MINIO_PRESIGNED_TTL_MINUTES", default=15)
 MINIO_DISABLE_CERT_CHECKS = env.bool("MINIO_DISABLE_CERT_CHECKS", default=False)
 
 
